Fixture media sources:

- `fixture_caption.jpg`: Wikimedia Commons thumbnail of `Fronalpstock_big.jpg`
- `fixture_group.png`: PNG conversion of Wikimedia Commons thumbnail of `Cat03.jpg`
- `fixture_receipt.jpg`: Wikimedia Commons thumbnail of `Moraine_Lake_17092005.jpg`
- `fixture_rcs.jpg`: Wikimedia Commons thumbnail of `Cat03.jpg`
- `fixture_attachment_only.jpg`: Wikimedia Commons thumbnail of `Fronalpstock_big.jpg`
- `fixture_clip.mp4`: 1-second MP4 generated locally from `fixture_caption.jpg`

These are bundled so Android fixture generation does not depend on the network.
